==> spirit_hub-0.1.1.26.tar.gz: spirit_hub-0.1.1.26/app/controllers/spirit_hub/search_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class SearchController < ApplicationController
    before_action :find_models, only: %i[index sort]
    before_action :set_seach_params, only: %i[index sort]
    before_action :skip_policy_scope, except: %i[index sort]

    include Datatablable

    def index
      authorize(Tagset, policy_class:)

      respond_to(&:html)
    end

    def sort
      authorize(Tagset, policy_class:)

      render partial: 'spirit_hub/search/table'
    end

    def users
      authorize(User, policy_class:)

      term = extract_term
      users = find_users(term)

      respond_to do |format|
        format.json do
          render json: SpiritHub::ActorFormatter.actors_to_json(users)
        end
      end
    end

    def users_or_groups
      authorize(User, policy_class:)

      term = extract_term
      users = find_users(term)
      groups = find_groups(term)

      respond_to do |format|
        format.json do
          render json: SpiritHub::ActorFormatter.actors_to_json(users + groups)
        end
      end
    end

    def actors
      authorize(User, policy_class:)

      term = extract_term
      users = find_users(term)
      groups = find_groups(term)
      contacts = find_contacts(term)

      respond_to do |format|
        format.json do
          render json: SpiritHub::ActorFormatter.actors_to_json(users + groups + contacts)
        end
      end
    end

    def tagset_docs_as_shared_attachments
      authorize(Tagset, policy_class:)

      return head(:not_found) if params[:tagset_id].blank?

      shared_tagset = Tagset.find_by!(id: params[:tagset_id])

      term = extract_term
      tagsets = Tagset.where.not(id: shared_tagset.id).where(
        type: 'document',
        operation_id: shared_tagset.operation_id,
        cleaned_main_key: { '$regex' => /#{term}/ }
      ).limit(10)

      respond_to do |format|
        format.json do
          render json: SpiritHub::TagsetFormatter.tagset_docs_as_shared_attachments_to_json(tagsets)
        end
      end
    end

    private

    def extract_term
      I18n.transliterate(Regexp.escape(params[:term]).accent_to_regexp).downcase
    end

    def find_users(term)
      User.where(cleaned_main_key: { '$regex' => /#{term}/ })
          .order_by(first_name: :asc)
          .limit(5)
    end

    def find_groups(term)
      Group.where(name: { '$regex' => /#{term}/i })
           .order_by(name: :asc)
           .limit(5)
    end

    def find_contacts(term)
      Doc.where(type: 'contact', title: { '$regex' => /#{term}/ })
         .order_by(name: :asc)
         .limit(5)
    end

    def find_models
      scope = policy_scope(Tagset.where(search_params), policy_scope_class:)
      @models = find_models_page(scope, default_sort_by: 'cleaned_main_key')
      @possible_states = SpiritHub::HubdocCycle.possible_current_states
      @last_current_user_options = SpiritHub::ActorFormatter.actors_to_select(User.all.limit(5))
    end

    def search_params
      permitted_params = params.require(:search_params).permit(:cleaned_main_key, :operation_id, :type, last_current_user_id: [], current_state: []).to_h

      permitted_params.each do |k, v|
        permitted_params[k] = v.reject(&:blank?)  if v.is_a?(Array)
        permitted_params.delete(k) if v.blank? || (v.is_a?(Array) && v.all?(&:blank?))
      end

      permitted_params = clean_params(permitted_params)
    end

    def set_seach_params
      @search_params = params[:search_params].to_unsafe_hash || {}
    end

    def clean_params(permitted_params)
      if permitted_params[:cleaned_main_key].present?
        permitted_params[:cleaned_main_key] = { '$regex' => /#{Regexp.escape(permitted_params[:cleaned_main_key]).accent_to_regexp}/i }
      end
      permitted_params[:current_state] = { '$in' => permitted_params[:current_state].compact } if permitted_params[:current_state].present?
      permitted_params[:last_current_user_id] = { '$in' => permitted_params[:last_current_user_id].compact } if permitted_params[:last_current_user_id].present?
      permitted_params
    end
  end
end

==> spirit_hub-0.1.1.34.tar.gz: spirit_hub-0.1.1.34/app/controllers/spirit_hub/search_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class SearchController < ApplicationController
    before_action :find_models, only: %i[index sort]
    before_action :set_seach_params, only: %i[index sort]
    before_action :skip_policy_scope, only: %i[users users users_or_groups actors]

    include Datatablable

    def index
      authorize(Tagset, policy_class:)

      respond_to(&:html)
    end

    def sort
      authorize(Tagset, policy_class:)

      render partial: 'spirit_hub/search/table'
    end

    def users
      authorize(User, policy_class:)

      term = extract_term
      users = find_users(term)

      respond_to do |format|
        format.json do
          render json: SpiritHub::ActorFormatter.actors_to_json(users)
        end
      end
    end

    def users_or_groups
      authorize(User, policy_class:)

      term = extract_term
      users = find_users(term)
      groups = find_groups(term)

      respond_to do |format|
        format.json do
          render json: SpiritHub::ActorFormatter.actors_to_json(users + groups)
        end
      end
    end

    def actors
      authorize(User, policy_class:)

      term = extract_term
      users = find_users(term)
      groups = find_groups(term)
      contacts = find_contacts(term)

      respond_to do |format|
        format.json do
          render json: SpiritHub::ActorFormatter.actors_to_json(users + groups + contacts)
        end
      end
    end

    def tagset_docs_as_shared_attachments
      authorize(Tagset, policy_class:)

      return head(:not_found) if params[:tagset_id].blank?

      shared_tagset = Tagset.find_by!(id: params[:tagset_id])

      term = extract_term
      scope = policy_scope(Tagset, policy_scope_class:)
      tagsets = scope.where.not(id: shared_tagset.id).where(
        type: 'document',
        operation_id: shared_tagset.operation_id,
        cleaned_main_key: { '$regex' => /#{term}/ }
      ).limit(10)

      respond_to do |format|
        format.json do
          render json: SpiritHub::TagsetFormatter.tagset_docs_as_shared_attachments_to_json(tagsets)
        end
      end
    end

    def docs_for_versioning
      authorize(Tagset, policy_class:)

      return head(:not_found) if params[:tagset_id].blank?

      scope = policy_scope(Tagset, policy_scope_class:)
      if params[:tagset_id] == 'all'
        documents = scope.where(cleaned_main_key: { '$regex' => /#{extract_term}/ }).limit(10)
      else
        versioning_tagset = scope.find_by!(id: params[:tagset_id])
        documents = versioning_tagset.docs.where(cleaned_main_key: { '$regex' => /#{extract_term}/ }).limit(10)
      end

      respond_to do |format|
        format.json do
          render json: documents.to_a.map { |t| { text: t.title, value: t.id.to_s } }
        end
      end
    end

    private

    def extract_term
      I18n.transliterate(Regexp.escape(params[:term]).accent_to_regexp).downcase
    end

    def find_users(term)
      User.where(cleaned_main_key: { '$regex' => /#{term}/ })
          .order_by(first_name: :asc)
          .limit(5)
    end

    def find_groups(term)
      Group.where(name: { '$regex' => /#{term}/i })
           .order_by(name: :asc)
           .limit(5)
    end

    def find_contacts(term)
      Doc.where(type: 'contact', title: { '$regex' => /#{term}/ })
         .order_by(name: :asc)
         .limit(5)
    end

    def find_models
      scope = policy_scope(Tagset.where(search_params), policy_scope_class:)
      @models = find_models_page(scope, default_sort_by: 'cleaned_main_key')
      @possible_states = SpiritHub::HubdocCycle.possible_current_states
      @last_current_user_options = SpiritHub::ActorFormatter.actors_to_select(User.all.limit(5))
    end

    def search_params
      permitted_params = params.require(:search_params).permit(:cleaned_main_key, :operation_id, :type, last_current_user_id: [], current_state: []).to_h

      permitted_params.each do |k, v|
        permitted_params[k] = v.reject(&:blank?)  if v.is_a?(Array)
        permitted_params.delete(k) if v.blank? || (v.is_a?(Array) && v.all?(&:blank?))
      end

      permitted_params = clean_params(permitted_params)
    end

    def set_seach_params
      @search_params = params[:search_params].to_unsafe_hash || {}
    end

    def clean_params(permitted_params)
      if permitted_params[:cleaned_main_key].present?
        permitted_params[:cleaned_main_key] = { '$regex' => /#{Regexp.escape(permitted_params[:cleaned_main_key]).accent_to_regexp}/i }
      end
      permitted_params[:current_state] = { '$in' => permitted_params[:current_state].compact } if permitted_params[:current_state].present?
      permitted_params[:last_current_user_id] = { '$in' => permitted_params[:last_current_user_id].compact } if permitted_params[:last_current_user_id].present?
      permitted_params
    end
  end
end
